vcf = '''
Content-type: text/x-vcard; charset=UTF-8

begin:vcard
VERSION:2.1
FBURL;PREF:http://test/%s.vfb
UID;charset=UTF-8:Citadel vCard: personal card for %s at test
n:%s;%s;;;
title:
fn:%s
org:
adr:;;;;;;
tel;home:
tel;work:
tel;fax:
tel;cell:
email;internet:%s
end:vcard
'''
