from distutils.core import setup
setup(
    name = 'citadel',
    packages = ['citadel'],
    version = '0.1',
    description = 'Citadel high level client library',
    author='Louis RIVIERE',
    author_email = "louis@pystew.net",
    url = "http://bitbucket.org/pystew/citadel",
    keywords = ["citadel", "client"],
    classifiers = [
        "Programming Language :: Python",
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Topic :: Software Development :: Libraries :: Python Modules",
        ],
    )
